module
Version:
v0.1.2
Opens a new window with list of versions in this module.
Published: Aug 15, 2025
License: MIT
Opens a new window with license information.
README
¶
Go Env Manager
Is a simple, light weight package to manage your env varaibles in a go project.
Features
- Load env variable from env files
- Bind structs to the env varaibles to provide a schema for your env files.
Methods
func LoadEnv(fileName string) loads the env variables from the env file.
func BindEnv(envStructPtr interface{}) binds the pointer to a struct to respective env variables (the name provided in the struct tags will be used)
Go env manager can parse env files with quotes, double quotes, back ticks. It also supports substituion of varaibles in the env file.
Directories
¶
Click to show internal directories.
Click to hide internal directories.